"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var enzyme_1 = require("enzyme");
var _1 = require("./");
var withRR4_1 = require("./withRR4");
var react_router_dom_1 = require("react-router-dom");
var SideNav_1 = require("react-sidenav/SideNav");
describe('withRR4', function () {
    it('selects the path when initial path is one from the nav item', function () {
        var SideNavWithRR4 = withRR4_1.withRR4();
        var wrapper = enzyme_1.mount((React.createElement(react_router_dom_1.MemoryRouter, { initialEntries: ["/def"], initialIndex: 0 },
            React.createElement(SideNavWithRR4, { defaultSelectedPath: 'abc' },
                React.createElement(_1.Nav, { id: "abc" }, "Nav"),
                React.createElement(_1.Nav, { id: "def" }, "Nav")))));
        var state = wrapper.find(SideNav_1.SideNav).get(0);
        expect(state.props.selectedPath).toBe('def');
    });
    it('selects the path when initial path is one from the nav item', function () {
        var SideNavWithRR4 = withRR4_1.withRR4();
        var Nav1 = function () { return (React.createElement("div", null, "Nav1")); };
        var Nav2 = function () { return (React.createElement("div", null, "Nav1")); };
        var Home = function () { return (React.createElement("div", null, "Home")); };
        var wrapper = enzyme_1.mount((React.createElement(react_router_dom_1.MemoryRouter, { initialEntries: [""], initialIndex: 0 },
            React.createElement("div", null,
                React.createElement(SideNavWithRR4, { defaultSelectedPath: 'home' },
                    React.createElement(_1.Nav, { id: "home" }, "Home"),
                    React.createElement(_1.Nav, { id: "link1" }, "Nav1"),
                    React.createElement(_1.Nav, { id: "link2" }, "Nav2")),
                React.createElement(react_router_dom_1.Route, { path: "/", exact: true, component: Home }),
                React.createElement(react_router_dom_1.Route, { path: "/home", component: Home }),
                React.createElement(react_router_dom_1.Route, { path: "/link1", component: Nav1 }),
                React.createElement(react_router_dom_1.Route, { path: "/link2", component: Nav2 })))));
        // ensure we render Home
        expect(wrapper.find(Home)).toHaveLength(1);
        // make sure Nav1 is not yet there
        expect(wrapper.find(Nav1)).toHaveLength(0);
        // now click Nav1/link1
        wrapper.find(_1.Nav).at(1).simulate("click");
        expect(wrapper.find(Nav1)).toHaveLength(1);
    });
    it('uses payload.to to route a Nav when clicked', function () {
        var SideNavWithRR4 = withRR4_1.withRR4();
        var HIJ = function () { return (React.createElement("div", null, "HIJ")); };
        var Home = function () { return (React.createElement("div", null, "Home")); };
        var wrapper = enzyme_1.mount((React.createElement(react_router_dom_1.MemoryRouter, { initialEntries: [""], initialIndex: 0 },
            React.createElement("div", null,
                React.createElement(SideNavWithRR4, { defaultSelectedPath: 'abc' },
                    React.createElement(_1.Nav, { id: "abc", payload: { to: 'hij' } }, "Nav"),
                    React.createElement(_1.Nav, { id: "def" }, "Nav")),
                React.createElement(react_router_dom_1.Route, { path: "/", exact: true, component: Home }),
                React.createElement(react_router_dom_1.Route, { path: "/hij", component: HIJ })))));
        // ensure we render Home
        expect(wrapper.find(Home)).toHaveLength(1);
        // make sure HIJ is not yet there
        expect(wrapper.find(HIJ)).toHaveLength(0);
        // now click Nav1/link1
        wrapper.find(_1.Nav).at(0).simulate("click");
        // make sure HIJ is not yet there
        expect(wrapper.find(HIJ)).toHaveLength(1);
    });
});
